@@ -1,4 +1,4 @@
-# $Id: BitrateCalc.pm,v 1.15 2005/07/23 08:14:15 joern Exp $
+# $Id: BitrateCalc.pm,v 1.16 2005/10/09 09:18:06 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -22,7 +22,7 @@ my $OGG_SIZE_OVERHEAD   = 0.25 / 100;
 my $VCD_VIDEO_RATE	= 1152;
 my $MAX_SVCD_SUM_RATE	= 2748;
 my $MAX_SVCD_VIDEO_RATE	= 2600;
-my $MAX_VIDEO_RATE	= 6000;
+my $MAX_VIDEO_RATE	= 9000;
 
 my %VORBIS_NOMINAL_BITRATES = (
 	0  =>  60,
@@ -341,6 +341,13 @@ sub calc_container_overhead {
 
 	$self->set_cont_overhead_size($container_overhead);
 
+	# calculate vcd multiplex bitrate reserve
+	my $vcd_reserve_bitrate =
+		$self->audio_bitrate +
+		int(($self->audio_bitrate + $self->video_bitrate)*0.02);
+
+	$self->set_vcd_reserve_bitrate($vcd_reserve_bitrate);
+
 	1;
 }
 
@@ -500,49 +507,18 @@ sub calc_video_size_and_bitrate {
 	# resulting video bitrate
 	my $video_bitrate = int($video_size/$runtime/1000*1024*1024*8);
 
-	my $comment = "(rounded)";
-	if ( $video_bitrate > $self->max_video_rate ) {
-		$video_bitrate = $self->max_video_rate;
-		$comment = " ".__x("(too high, set to {max_video_rate})",
-				   max_video_rate => $self->max_video_rate);
-	}
-	
-	if ( $title->tc_video_codec =~ /^(X?SVCD|CVD|XVCD)$/ and
-	     $video_bitrate + $audio_bitrate > $self->max_svcd_sum_rate ) {
-		$video_bitrate = $self->max_svcd_sum_rate - $audio_bitrate;
-		$comment = " ".__"(too high, limited)";
-	}
-
-	if ( $title->tc_video_codec =~ /^(X?SVCD|CVD|XVCD)$/ and
-	     $video_bitrate > $self->max_svcd_video_rate ) {
-		$video_bitrate = $self->max_svcd_video_rate;
-		$comment = " ".__"(too high, limited)";
-	}
-
-	if ( $title->tc_video_codec =~ /^X?VCD$/ and
-	     $title->tc_video_bitrate_mode ne 'manual' ) {
-		$video_bitrate = $self->vcd_video_rate;
-		$comment = " ".__"(VCD has fixed rate)";
-	}
-
-	if ( $title->tc_video_bitrate_mode eq 'bpp' ) {
-		my $pps = $title->frame_rate * $width * $height;
-		my $bpp = $title->tc_video_bpp_manual;
-		$video_bitrate = int($bpp * $pps / 1000);
-		$comment = " ".__x("(from bpp {bpp})", bpp => $bpp);
-
-	} elsif ( $title->tc_video_bitrate_mode eq 'manual' ) {
-		$video_bitrate = $title->tc_video_bitrate_manual;
-		$comment = " ".__"(manual setting)";
-	}
-
 	$self->add_to_sheet ({
-		label    => __("Resulting video bitrate").$comment,
+		label    => __("Resulting video bitrate, rounded"),
 		operator => "~",
 		value    => $video_bitrate,
 		unit     => "kbit/s",
 	});
 
+	# probably too high for selected video codec
+	$video_bitrate = $self->calc_video_bitrate_limit (
+		video_bitrate => $video_bitrate,
+	);
+
 	# calculate bpp
 	my $bpp = 0;
 	if ( $title->tc_video_bitrate_mode eq 'bpp' ) {
@@ -571,19 +547,58 @@ sub calc_video_size_and_bitrate {
 		unit     => "MB",
 	});
 
-	# calculate vcd multiplex bitrate reserve
-	my $vcd_reserve_bitrate =
-		$audio_bitrate +
-		int(($audio_bitrate + $video_bitrate)*0.02);
-
-
 	$self->set_video_bitrate($video_bitrate);
 	$self->set_video_bpp($bpp);
 	$self->set_video_size($video_size);
-	$self->set_vcd_reserve_bitrate($vcd_reserve_bitrate);
+
 	1;
 }
 
+sub calc_video_bitrate_limit {
+	my $self = shift;
+	my %par = @_;
+	my ($video_bitrate) = @par{'video_bitrate'};
+
+	my $title   = $self->title;
+	my $audio_bitrate = $self->audio_bitrate;
+
+	my $comment;
+	if ( $video_bitrate > $self->max_video_rate ) {
+		$video_bitrate = $self->max_video_rate;
+		$comment = __x("Bitrate too high, set to {max_video_rate}",
+				   max_video_rate => $self->max_video_rate);
+	}
+	
+	if ( $title->tc_video_codec =~ /^(SVCD|CVD|VCD)$/ and
+	     $video_bitrate + $audio_bitrate > $self->max_svcd_sum_rate ) {
+		$video_bitrate = $self->max_svcd_sum_rate - $audio_bitrate;
+		$comment = __"Bitrate too high, limited";
+	}
+
+	if ( $title->tc_video_codec =~ /^(SVCD|CVD|VCD)$/ and
+	     $video_bitrate > $self->max_svcd_video_rate ) {
+		$video_bitrate = $self->max_svcd_video_rate;
+		$comment = __"Bitrate too high, limited";
+	}
+
+	if ( $title->tc_video_codec =~ /^VCD$/ and
+	     $title->tc_video_bitrate_mode ne 'manual' ) {
+		$video_bitrate = $self->vcd_video_rate;
+		$comment = __"VCD has fixed rate";
+	}
+
+	if ( $comment ) {
+		$self->add_to_sheet ({
+			label    => $comment,
+			operator => "=",
+			value    => $video_bitrate,
+			unit     => "kbit/s",
+		});
+	}
+
+	return $video_bitrate;
+}
+
 sub calc_video_size_from_bitrate {
 	my $self = shift;
 	
@@ -612,6 +627,9 @@ sub calc_video_size_from_bitrate {
 			value    => $video_bitrate,
 			unit     => "kbit/s",
 		});
+		$video_bitrate = $self->calc_video_bitrate_limit (
+			video_bitrate => $video_bitrate,
+		);
 	} else {
 		$video_bpp = $video_bitrate * 1000 / $pps if $pps != 0;
 		$video_bpp = sprintf("%.3f", $video_bpp);
@@ -621,8 +639,11 @@ sub calc_video_size_from_bitrate {
 			value    => $video_bitrate,
 			unit     => "kbit/s",
 		});
+		$video_bitrate = $self->calc_video_bitrate_limit (
+			video_bitrate => $video_bitrate,
+		);
 		$self->add_to_sheet ({
-			label    => __"Resulting Video Bitrate",
+			label    => __"Resulting BPP",
 			operator => "~",
 			value    => $video_bpp,
 			unit     => "bpp",
