@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.52 2005/08/01 19:31:10 joern Exp $
+# $Id: Config.pm,v 1.53 2005/10/09 09:24:20 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -691,7 +691,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or die "can't write $filename";
-	print $fh q{# $Id: Config.pm,v 1.52 2005/08/01 19:31:10 joern Exp $},"\n";
+	print $fh q{# $Id: Config.pm,v 1.53 2005/10/09 09:24:20 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
@@ -733,19 +733,7 @@ sub set_value {
 	my $config = $self->config;
 	confess "Unknown config parameter '$name'"
 		if not exists $config->{$name};
-
-	my $db_value = $value;
-	$config->{$name}->{value} = $value;
-
-	if ( $config->{$name}->{type} eq 'list' ) {
-		my $dump = Dumper($value);
-		$dump =~ s/^.VAR.\s*=\s*//;
-		$db_value = $dump;
-	}
-	
-	$self->config->{$name}->{value} = $value;
-	
-	return $value;
+	return $config->{$name}->{value} = $value;
 }
 
 sub entries_by_type {
@@ -765,7 +753,7 @@ sub entries_by_type {
 sub set_temporary {
 	my $self = shift;
 	my ($name, $value) = @_;
-	$self->config->{$name}->{value} = $value;
+	return $self->config->{$name}->{value} = $value;
 }
 
 sub get_preset {
@@ -782,6 +770,17 @@ sub get_preset {
 	return;
 }
 
+sub copy_values_from {
+	my $self = shift;
+	my ($config) = @_;
+	
+	foreach my $par ( keys %CONFIG_PARAMETER ) {
+		$self->set_value($par, $config->get_value($par));
+	}
+
+	1;
+}
+
 #---------------------------------------------------------------------
 # Test methods
 #---------------------------------------------------------------------
@@ -790,8 +789,8 @@ sub test_play_dvd_command   	{ _executable (@_) 	}
 sub test_play_file_command  	{ _executable (@_) 	}
 sub test_play_stdin_command 	{ _executable (@_) 	}
 sub test_rar_command 		{ _executable (@_) 	}
-sub test_dvd_device		{ _writable (@_)	}
-sub test_writer_device		{ _writable (@_)	}
+sub test_dvd_device		{ _exists (@_)		}
+sub test_writer_device		{ _exists (@_)		}
 sub test_dvd_mount_point	{ _exists (@_)		}
 sub test_base_project_dir	{ _writable (@_)	}
 sub test_dvdrip_files_dir	{ _writable (@_)	}
